pub struct InputAttributes {
pub track_definitions: Option<Vec<TrackDefinition>>,
}Expand description
Input attributes that provide additional information about the input asset.
This type is not used in any activity, and only used as part of another schema.
Fields
track_definitions: Option<Vec<TrackDefinition>>Optional. A list of track definitions for the input asset.