pub struct Job {Show 16 fields
pub batch_mode_priority: Option<i32>,
pub config: Option<JobConfig>,
pub create_time: Option<DateTime<Utc>>,
pub end_time: Option<DateTime<Utc>>,
pub error: Option<Status>,
pub fill_content_gaps: Option<bool>,
pub input_uri: Option<String>,
pub labels: Option<HashMap<String, String>>,
pub mode: Option<String>,
pub name: Option<String>,
pub optimization: Option<String>,
pub output_uri: Option<String>,
pub start_time: Option<DateTime<Utc>>,
pub state: Option<String>,
pub template_id: Option<String>,
pub ttl_after_completion_days: Option<i32>,
}Expand description
Transcoding job resource.
Activities
This type is used in activities, which are methods you may call on this type or where this type is involved in. The list links the activity name, along with information about where it is used (one of request and response).
- locations jobs create projects (request|response)
- locations jobs get projects (response)
Fields
batch_mode_priority: Option<i32>The processing priority of a batch job. This field can only be set for batch mode jobs. The default value is 0. This value cannot be negative. Higher values correspond to higher priorities for the job.
config: Option<JobConfig>The configuration for this job.
create_time: Option<DateTime<Utc>>Output only. The time the job was created.
end_time: Option<DateTime<Utc>>Output only. The time the transcoding finished.
error: Option<Status>Output only. An error object that describes the reason for the failure. This property is always present when ProcessingState is FAILED.
fill_content_gaps: Option<bool>Optional. Insert silence and duplicate frames when timestamp gaps are detected in a given stream.
input_uri: Option<String>Input only. Specify the input_uri to populate empty uri fields in each element of Job.config.inputs or JobTemplate.config.inputs when using template. URI of the media. Input files must be at least 5 seconds in duration and stored in Cloud Storage (for example, gs://bucket/inputs/file.mp4). See Supported input and output formats.
labels: Option<HashMap<String, String>>The labels associated with this job. You can use these to organize and group your jobs.
mode: Option<String>The processing mode of the job. The default is PROCESSING_MODE_INTERACTIVE.
name: Option<String>The resource name of the job. Format: projects/{project_number}/locations/{location}/jobs/{job}
optimization: Option<String>Optional. The optimization strategy of the job. The default is AUTODETECT.
output_uri: Option<String>Input only. Specify the output_uri to populate an empty Job.config.output.uri or JobTemplate.config.output.uri when using template. URI for the output file(s). For example, gs://my-bucket/outputs/. See Supported input and output formats.
start_time: Option<DateTime<Utc>>Output only. The time the transcoding started.
state: Option<String>Output only. The current state of the job.
template_id: Option<String>Input only. Specify the template_id to use for populating Job.config. The default is preset/web-hd, which is the only supported preset. User defined JobTemplate: {job_template_id}
ttl_after_completion_days: Option<i32>Job time to live value in days, which will be effective after job completion. Job should be deleted automatically after the given TTL. Enter a value between 1 and 90. The default is 30.