pub struct MuxStream {
pub container: Option<String>,
pub elementary_streams: Option<Vec<String>>,
pub encryption_id: Option<String>,
pub file_name: Option<String>,
pub fmp4: Option<Fmp4Config>,
pub key: Option<String>,
pub segment_settings: Option<SegmentSettings>,
}Expand description
Multiplexing settings for output stream.
This type is not used in any activity, and only used as part of another schema.
Fields
container: Option<String>The container format. The default is mp4 Supported streaming formats: - ts - fmp4- the corresponding file extension is .m4s Supported standalone file formats: - mp4 - mp3 - ogg - vtt See also: Supported input and output formats
elementary_streams: Option<Vec<String>>List of ElementaryStream.key values multiplexed in this stream.
encryption_id: Option<String>Identifier of the encryption configuration to use. If omitted, output will be unencrypted.
file_name: Option<String>The name of the generated file. The default is MuxStream.key with the extension suffix corresponding to the MuxStream.container. Individual segments also have an incremental 10-digit zero-padded suffix starting from 0 before the extension, such as mux_stream0000000123.ts.
fmp4: Option<Fmp4Config>Optional. fmp4 container configuration.
key: Option<String>A unique key for this multiplexed stream.
segment_settings: Option<SegmentSettings>Segment settings for ts, fmp4 and vtt.