pub struct TrackDefinition {
pub detect_languages: Option<bool>,
pub detected_languages: Option<Vec<String>>,
pub input_track: Option<i32>,
pub languages: Option<Vec<String>>,
}Expand description
Track definition for the input asset.
This type is not used in any activity, and only used as part of another schema.
Fields
detect_languages: Option<bool>Optional. Whether to automatically detect the languages present in the track. If true, the system will attempt to identify all the languages present in the track and populate the languages field.
detected_languages: Option<Vec<String>>Output only. A list of languages detected in the input asset, represented by a BCP 47 language code, such as “en-US” or “sr-Latn”. For more information, see https://www.unicode.org/reports/tr35/#Unicode_locale_identifier. This field is only populated if the detect_languages field is set to true.
input_track: Option<i32>The input track.
languages: Option<Vec<String>>Optional. A list of languages spoken in the input asset, represented by a BCP 47 language code, such as “en-US” or “sr-Latn”. For more information, see https://www.unicode.org/reports/tr35/#Unicode_locale_identifier.